<?php
defined('_JEXEC') or die;

/**
 * Joomla User plugin
 *
 * @since  1.5
 */
class PlgUserOSMembership extends JPlugin
{
	/**
	 * Application object
	 *
	 * @var    JApplicationCms
	 * @since  3.2
	 */
	protected $app;

	/**
	 * Database object
	 *
	 * @var    JDatabaseDriver
	 * @since  3.2
	 */
	protected $db;

	/**
	 * Remove all sessions for the user name
	 *
	 * Method is called after user data is deleted from the database
	 *
	 * @param   array $oldUser Holds the old user data
	 * @param   bool  $isNew   True if user is created now
	 * @param   array $user    Current user data
	 *
	 * @return  boolean
	 *
	 */
	public function onUserBeforeSave($oldUser, $isNew, $user)
	{
		if (!$isNew && $oldUser['block'] == 1 && $user['block'] == 0)
		{
			// User is approved, we need to find the subscription record and re-calculate the start date and end date
			$db    = JFactory::getDbo();
			$query = $db->getQuery(true);
			$query->select('id')
				->from('#__osmembership_subscribers')
				->where('user_id = ' . (int) $user['id'])
				->where('published IN (0, 1)')
				->order('id DESC');
			$db->setQuery($query);
			$subscriptionRecordId = (int) $db->loadResult();
			if ($subscriptionRecordId)
			{
				require_once JPATH_ADMINISTRATOR . '/components/com_osmembership/table/osmembership.php';
				$row = JTable::getInstance('OsMembership', 'Subscriber');
				$row->load($subscriptionRecordId);
				$createdDate = JFactory::getDate($row->created_date);
				$fromDate    = JFactory::getDate($row->from_date);
				$toDate      = JFactory::getDate($row->to_date);
				$todayDate   = JFactory::getDate('now');
				$diff        = $createdDate->diff($todayDate);
				$fromDate->add($diff);
				$toDate->add($diff);
				$row->from_date = $fromDate->toSql();
				$row->to_date   = $toDate->toSql();
				$row->store();
			}
		}

		return true;
	}
}
